summaryrefslogtreecommitdiffstats
path: root/kmymoney2/mymoney/mymoneyinstitution.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/mymoney/mymoneyinstitution.h')
-rw-r--r--kmymoney2/mymoney/mymoneyinstitution.h92
1 files changed, 46 insertions, 46 deletions
diff --git a/kmymoney2/mymoney/mymoneyinstitution.h b/kmymoney2/mymoney/mymoneyinstitution.h
index 35b44c5..47d9321 100644
--- a/kmymoney2/mymoney/mymoneyinstitution.h
+++ b/kmymoney2/mymoney/mymoneyinstitution.h
@@ -24,10 +24,10 @@
// ----------------------------------------------------------------------------
// QT Includes
-#include <qstring.h>
-#include <qmap.h>
-#include <qstringlist.h>
-#include <qpixmap.h>
+#include <tqstring.h>
+#include <tqmap.h>
+#include <tqstringlist.h>
+#include <tqpixmap.h>
// ----------------------------------------------------------------------------
// Project Includes
@@ -58,13 +58,13 @@ public:
* values required for a new institution. This object should then be
* passed to @see MyMoneyFile::addInstitution
*/
- MyMoneyInstitution(const QString& name,
- const QString& city,
- const QString& street,
- const QString& postcode,
- const QString& telephone,
- const QString& manager,
- const QString& sortCode);
+ MyMoneyInstitution(const TQString& name,
+ const TQString& city,
+ const TQString& street,
+ const TQString& postcode,
+ const TQString& telephone,
+ const TQString& manager,
+ const TQString& sortCode);
/**
* This is the destructor for any MyMoneyInstitution object
@@ -77,34 +77,34 @@ public:
* @param id id assigned to the new institution object
* @param right institution definition
*/
- MyMoneyInstitution(const QString& id, const MyMoneyInstitution& right);
+ MyMoneyInstitution(const TQString& id, const MyMoneyInstitution& right);
/**
* This is the constructor for an institution that is described by a
- * QDomElement (e.g. from a file).
+ * TQDomElement (e.g. from a file).
*
* @param el const reference to the QDomElement from which to
* create the object
*/
- MyMoneyInstitution(const QDomElement& el);
+ MyMoneyInstitution(const TQDomElement& el);
- const QString& manager(void) const { return m_manager; }
- const QString& name(void) const { return m_name; }
- const QString& postcode(void) const { return m_postcode; }
- const QString& street(void) const { return m_street; }
- const QString& telephone(void) const { return m_telephone; }
- const QString& town(void) const { return m_town; }
- const QString& city(void) const { return town(); }
- const QString& sortcode(void) const { return m_sortcode; }
+ const TQString& manager(void) const { return m_manager; }
+ const TQString& name(void) const { return m_name; }
+ const TQString& postcode(void) const { return m_postcode; }
+ const TQString& street(void) const { return m_street; }
+ const TQString& telephone(void) const { return m_telephone; }
+ const TQString& town(void) const { return m_town; }
+ const TQString& city(void) const { return town(); }
+ const TQString& sortcode(void) const { return m_sortcode; }
- void setManager(QString manager) { m_manager = manager; }
- void setName(QString name) { m_name = name; }
- void setPostcode(QString code) { m_postcode = code; }
- void setStreet(QString street) { m_street = street; }
- void setTelephone(QString tel) { m_telephone = tel; }
- void setTown(QString town) { m_town = town; }
- void setCity(QString town) { setTown(town); }
- void setSortcode(QString code) { m_sortcode = code; }
+ void setManager(TQString manager) { m_manager = manager; }
+ void setName(TQString name) { m_name = name; }
+ void setPostcode(TQString code) { m_postcode = code; }
+ void setStreet(TQString street) { m_street = street; }
+ void setTelephone(TQString tel) { m_telephone = tel; }
+ void setTown(TQString town) { m_town = town; }
+ void setCity(TQString town) { setTown(town); }
+ void setSortcode(TQString code) { m_sortcode = code; }
/**
* This method adds the id of an account to the account list of
@@ -113,7 +113,7 @@ public:
*
* @param account id of the account to be added
*/
- void addAccountId(const QString& account);
+ void addAccountId(const TQString& account);
/**
* This method deletes the id of an account from the account list
@@ -122,14 +122,14 @@ public:
* @param account id of the account to be deleted
* @return id of account deleted, otherwise empty string
*/
- QString removeAccountId(const QString& account);
+ TQString removeAccountId(const TQString& account);
/**
* This method is used to return the set of accounts known to
* this institution
* return QStringList of account ids
*/
- const QStringList& accountList(void) const { return m_accountList; }
+ const TQStringList& accountList(void) const { return m_accountList; }
/**
* This method returns the number of accounts known to
@@ -141,7 +141,7 @@ public:
bool operator == (const MyMoneyInstitution&) const;
bool operator < (const MyMoneyInstitution& right) const;
- void writeXML(QDomDocument& document, QDomElement& parent) const;
+ void writeXML(TQDomDocument& document, TQDomElement& tqparent) const;
/**
* This method checks if a reference to the given object exists. It returns,
@@ -152,55 +152,55 @@ public:
* @retval true This object references object with id @p id.
* @retval false This object does not reference the object with id @p id.
*/
- virtual bool hasReferenceTo(const QString& id) const;
+ virtual bool hasReferenceTo(const TQString& id) const;
- QPixmap pixmap() const;
+ TQPixmap pixmap() const;
private:
// Bank 'fields'
/**
* This member variable keeps the name of the institution
*/
- QString m_name;
+ TQString m_name;
/**
* This member variable keeps the city of the institution
*/
- QString m_town;
+ TQString m_town;
/**
* This member variable keeps the street of the institution
*/
- QString m_street;
+ TQString m_street;
/**
* This member variable keeps the zip-code of the institution
*/
- QString m_postcode;
+ TQString m_postcode;
/**
* This member variable keeps the telephone number of the institution
*/
- QString m_telephone;
+ TQString m_telephone;
/**
* This member variable keeps the name of the representative of
* the institution
*/
- QString m_manager;
+ TQString m_manager;
/**
* This member variable keeps the sort code of the institution.
* FIXME: I have no idea
* what it is good for. I keep it because it was in the old engine.
*/
- QString m_sortcode;
+ TQString m_sortcode;
/**
* This member variable keeps the sorted list of the account ids
* available at this institution
*/
- QStringList m_accountList;
+ TQStringList m_accountList;
};
#endif
@@ -77,34 +77,34 @@ public:
*
- * @param el const reference to the QDomElement from which to
+ * @param el const reference to the TQDomElement from which to
* create the object
*/
@@ -122,14 +122,14 @@ public:
* This method is used to return the set of accounts known to
* this institution
- * return QStringList of account ids
+ * return TQStringList of account ids
*/